@@ -187,12 +187,30 @@ class AttributePanel extends BlankPanel {
 					break;
 				}
 			}
+
 			String superior = null;
 			LDAPAttributeSchema las =
 				new LDAPAttributeSchema(name, oid, desc,
 										syntaxOID,
 										!multi, superior, aliases);
 			las.setQualifier("X-ORIGIN", "user defined");
+
+			// Set the matching rules if any were selected
+			String selectedEqMatchingRule = (String)_cmbAttributeMrEquality.getSelectedItem();
+			if ((selectedEqMatchingRule != null) && (!selectedEqMatchingRule.equalsIgnoreCase("none"))) {
+				las.setQualifier("EQUALITY", selectedEqMatchingRule);
+			}
+
+			String selectedOrdMatchingRule = (String)_cmbAttributeMrOrdering.getSelectedItem();
+			if ((selectedOrdMatchingRule != null) && (!selectedOrdMatchingRule.equalsIgnoreCase("none"))) {
+				las.setQualifier("ORDERING", selectedOrdMatchingRule);
+			}
+
+			String selectedSubMatchingRule = (String)_cmbAttributeMrSubstring.getSelectedItem();
+			if ((selectedSubMatchingRule != null) && (!selectedSubMatchingRule.equalsIgnoreCase("none"))) {
+				las.setQualifier("SUBSTR", selectedSubMatchingRule);
+			}
+
 			boolean done = false;
 			boolean deleted = false;
 			boolean status = false;
@@ -475,7 +493,99 @@ class AttributePanel extends BlankPanel {
 				}
 			}
 		}
-		
+
+		/* check if the EQUALITY matching rule can be used with the syntax */
+		boolean isEqMatchingRuleValid = true;
+		boolean isEqMatchingRuleModified = false;
+		String selectedEqMatchingRule = (String)_cmbAttributeMrEquality.getSelectedItem();
+		String originalEqMatchingRule = null;
+		String selectedEqSyntax = null;
+
+		if (_las != null) {
+			String [] mr_eq_vals = _las.getQualifier("EQUALITY");
+			if ((mr_eq_vals != null) && (mr_eq_vals.length > 0)) {
+				originalEqMatchingRule = mr_eq_vals[0];
+			}
+
+			if (selectedEqMatchingRule != null) {
+				// was the matching rule modified?
+				if ((originalEqMatchingRule != null) && !originalEqMatchingRule.equals(selectedEqMatchingRule)) {
+					isEqMatchingRuleModified = true;
+				}
+			}
+		}
+
+		// get the name of the syntax used in the matching rule
+		if ((selectedEqMatchingRule != null) && (_htMatchingRuleStrings.get(selectedEqMatchingRule) != null)) {
+			selectedEqSyntax = (String)_htSyntaxStrings.get(_htMatchingRuleStrings.get(selectedEqMatchingRule));
+		}
+
+		// is the matching rule valid?
+		if ((selectedEqSyntax != null) && !selectedEqSyntax.equals(selectedSyntax)) {
+			isEqMatchingRuleValid = false;
+		}
+
+		/* check if the ORDERING matching rule can be used with the syntax */
+		boolean isOrdMatchingRuleValid = true;
+		boolean isOrdMatchingRuleModified = false;
+		String selectedOrdMatchingRule = (String)_cmbAttributeMrOrdering.getSelectedItem();
+		String originalOrdMatchingRule = null;
+		String selectedOrdSyntax = null;
+
+		if (_las != null) {
+			String [] mr_ord_vals = _las.getQualifier("ORDERING");
+			if ((mr_ord_vals != null) && (mr_ord_vals.length > 0)) {
+				originalOrdMatchingRule = mr_ord_vals[0];
+			}
+
+			if (selectedOrdMatchingRule != null) {
+				// was the matching rule modified?
+				if ((originalOrdMatchingRule != null) && !originalOrdMatchingRule.equals(selectedOrdMatchingRule)) {
+					isOrdMatchingRuleModified = true;
+				}
+			}
+		}
+
+		// get the name of the syntax used in the matching rule
+		if ((selectedOrdMatchingRule != null) && (_htMatchingRuleStrings.get(selectedOrdMatchingRule) != null)) {
+			selectedOrdSyntax = (String)_htSyntaxStrings.get(_htMatchingRuleStrings.get(selectedOrdMatchingRule));
+		}
+
+		// is the matching rule valid?
+		if ((selectedOrdSyntax != null) && !selectedOrdSyntax.equals(selectedSyntax)) {
+			isOrdMatchingRuleValid = false;
+		}
+
+		/* check if the SUBSTR matching rule can be used with the syntax */
+		boolean isSubMatchingRuleValid = true;
+		boolean isSubMatchingRuleModified = false;
+		String selectedSubMatchingRule = (String)_cmbAttributeMrSubstring.getSelectedItem();
+		String originalSubMatchingRule = null;
+		String selectedSubSyntax = null;
+
+		if (_las != null) {
+			String [] mr_sub_vals = _las.getQualifier("SUBSTR");
+			if ((mr_sub_vals != null) && (mr_sub_vals.length > 0)) {
+				originalSubMatchingRule = mr_sub_vals[0];
+			}
+
+			if (selectedSubMatchingRule != null) {
+				// was the matching rule modified?
+				if ((originalSubMatchingRule != null) && !originalSubMatchingRule.equals(selectedSubMatchingRule)) {
+					isSubMatchingRuleModified = true;
+				}
+			}
+		}
+
+		// get the name of the syntax used in the matching rule
+		if ((selectedSubMatchingRule != null) && (_htMatchingRuleStrings.get(selectedSubMatchingRule) != null)) {
+			selectedSubSyntax = (String)_htSyntaxStrings.get(_htMatchingRuleStrings.get(selectedSubMatchingRule));
+		}
+
+		// is the matching rule valid?
+		if ((selectedSubSyntax != null) && !selectedSubSyntax.equals(selectedSyntax)) {
+			isSubMatchingRuleValid = false;
+		}
 
 		/* CHECK MULTIVALUED (always valid, only modification) */		
 		boolean isMultiValuedModified = false;
@@ -522,6 +632,29 @@ class AttributePanel extends BlankPanel {
 			setChangeState(_lAttributeSyntax, CHANGE_STATE_UNMODIFIED);		
 		}
 
+		if (!isEqMatchingRuleValid) {
+			setChangeState(_lAttributeMrEquality, CHANGE_STATE_ERROR);
+		} else if (isEqMatchingRuleModified) {
+			setChangeState(_lAttributeMrEquality, CHANGE_STATE_MODIFIED);
+		} else {
+			setChangeState(_lAttributeMrEquality, CHANGE_STATE_UNMODIFIED);
+		}
+
+		if (!isOrdMatchingRuleValid) {
+			setChangeState(_lAttributeMrOrdering, CHANGE_STATE_ERROR);
+		} else if (isOrdMatchingRuleModified) {
+			setChangeState(_lAttributeMrOrdering, CHANGE_STATE_MODIFIED);
+		} else {
+			setChangeState(_lAttributeMrOrdering, CHANGE_STATE_UNMODIFIED);
+		}
+
+		if (!isSubMatchingRuleValid) {
+			setChangeState(_lAttributeMrSubstring, CHANGE_STATE_ERROR);
+		} else if (isSubMatchingRuleModified) {
+			setChangeState(_lAttributeMrSubstring, CHANGE_STATE_MODIFIED);
+		} else {
+			setChangeState(_lAttributeMrSubstring, CHANGE_STATE_UNMODIFIED);
+		}
 
 		if (isMultiValuedModified) {			
 			setChangeState(_ckbAttributeIsMulti, CHANGE_STATE_MODIFIED);			
@@ -531,7 +664,8 @@ class AttributePanel extends BlankPanel {
 
 		boolean isValid = isNameValid &&
 			isAliasValid &&
-			isOIDValid;
+			isOIDValid && isEqMatchingRuleValid &&
+			isOrdMatchingRuleValid && isSubMatchingRuleValid;
 		
 		_dlg.setOKButtonEnabled( isValid );		
 	}
@@ -550,35 +684,45 @@ class AttributePanel extends BlankPanel {
     }
 
 	protected JPanel createNewAttributeArea() {
-	    // create the widgets
-	    _lAttributeName = makeJLabel(PANEL_NAME, "newname");
-	    _tfAttributeName = makeJTextField(PANEL_NAME, "newname",
+		/* In _htSyntaxStrings we have as key the OID of the syntax, and as value, the Description of the Syntax */
+                if ( _htSyntaxStrings == null ) {
+                        _htSyntaxStrings = SchemaAttributesPanel.getSyntaxStrings(getModel().getSchema());
+                }
+
+                // In _htMatchingRuleStrings we have as key the name of the MR, and as value, the AVA syntax OID
+                if ( _htMatchingRuleStrings == null ) {
+                        _htMatchingRuleStrings = SchemaAttributesPanel.getMatchingRuleStrings(getModel().getSchema());
+                }
+
+		// create the widgets
+		_lAttributeName = makeJLabel(PANEL_NAME, "newname");
+		_tfAttributeName = makeJTextField(PANEL_NAME, "newname",
 	                                      null, 20);
 		_lAttributeName.setLabelFor(_tfAttributeName);
 
 		_lAttributeAliases = makeJLabel(PANEL_NAME, "newaliases");
-	    _tfAttributeAliases = makeJTextField(PANEL_NAME, "newaliases",
+		_tfAttributeAliases = makeJTextField(PANEL_NAME, "newaliases",
 											 null, 20);
 		_lAttributeAliases.setLabelFor(_tfAttributeAliases);
 
-	    _lAttributeOID = makeJLabel(PANEL_NAME, "newoid");
-	    _tfAttributeOID = makeJTextField(PANEL_NAME, "newoid",
+		_lAttributeOID = makeJLabel(PANEL_NAME, "newoid");
+		_tfAttributeOID = makeJTextField(PANEL_NAME, "newoid",
 	                                     null, 20);
 		_lAttributeOID.setLabelFor(_tfAttributeOID);
 
-	    _lAttributeDesc = makeJLabel(PANEL_NAME, "newdesc");
-	    _tfAttributeDesc = makeJTextField(PANEL_NAME, "newdesc",
+		_lAttributeDesc = makeJLabel(PANEL_NAME, "newdesc");
+		_tfAttributeDesc = makeJTextField(PANEL_NAME, "newdesc",
 	                                      null, 20);
 		_lAttributeDesc.setLabelFor(_tfAttributeDesc);
 
-	    _ckbAttributeIsMulti = makeJCheckBox(PANEL_NAME, "newmulti",
+		_ckbAttributeIsMulti = makeJCheckBox(PANEL_NAME, "newmulti",
 	                                         false);
 		// Value by default
 		_ckbAttributeIsMulti.setSelected(true);
 		_ckbAttributeIsMulti.addActionListener(this);
 
-	    _lAttributeSyntax = makeJLabel(PANEL_NAME, "newsyntax");
-	    _cmbAttributeSyntax = makeJComboBox(PANEL_NAME, "newsyntax",
+		_lAttributeSyntax = makeJLabel(PANEL_NAME, "newsyntax");
+		_cmbAttributeSyntax = makeJComboBox(PANEL_NAME, "newsyntax",
 	                                        null);
 		_lAttributeSyntax.setLabelFor(_cmbAttributeSyntax);
 		_cmbAttributeSyntax.addItemListener(this);
@@ -593,12 +737,38 @@ class AttributePanel extends BlankPanel {
 			if ( c instanceof JTextField )
 				((JTextField)c).setMargin( getTextInsets() );
 		}
-		/* In _htSyntaxStrings we have as key the OID of the syntax, and as value, the Description of the Syntax */
-		if ( _htSyntaxStrings == null ) {
-			_htSyntaxStrings = SchemaAttributesPanel.getSyntaxStrings(getModel().getSchema());
+
+		// Equality matching rules
+		_lAttributeMrEquality = makeJLabel(PANEL_NAME, "newmrequality");
+		_cmbAttributeMrEquality = makeJComboBox(PANEL_NAME, "newmrequality",
+							null);
+		_lAttributeMrEquality.setLabelFor(_cmbAttributeMrEquality);
+		_cmbAttributeMrEquality.addItemListener(this);
+		UIFactory.setToolTip(PANEL_NAME, "newmrequality", _cmbAttributeMrEquality);
+		ed = _cmbAttributeMrEquality.getEditor();
+		if ( ed != null ) {
+			Component c = ed.getEditorComponent();
+			if ( c instanceof JTextField )
+				((JTextField)c).setMargin( getTextInsets() );
 		}
+
+		// Ordering matching rules
+		_lAttributeMrOrdering = makeJLabel(PANEL_NAME, "newmrordering");
+		_cmbAttributeMrOrdering = makeJComboBox(PANEL_NAME, "newmrordering",
+						null);
+		_lAttributeMrOrdering.setLabelFor(_cmbAttributeMrOrdering);
+		_cmbAttributeMrOrdering.addItemListener(this);
+
+
+		// Substring matching rules
+		_lAttributeMrSubstring = makeJLabel(PANEL_NAME, "newmrsubstring");
+		_cmbAttributeMrSubstring = makeJComboBox(PANEL_NAME, "newmrsubstring",
+						null);
+		_lAttributeMrSubstring.setLabelFor(_cmbAttributeMrSubstring);
+		_cmbAttributeMrSubstring.addItemListener(this);
+
 		/* We add the different syntaxes to the combobox */
-		Enumeration syntaxes = _htSyntaxStrings.elements();		
+		Enumeration syntaxes = _htSyntaxStrings.elements();
 		while (syntaxes.hasMoreElements()) {
 			String item = (String)syntaxes.nextElement();
 			if (item != null) {
@@ -606,9 +776,28 @@ class AttributePanel extends BlankPanel {
 			}
 		}
 
-        // layout the widgets
-        // create a panel to hold things
-        JPanel panel = new JPanel(new GridBagLayout());
+		// Fill in the combo boxes with a sorted list of matching rules
+		_cmbAttributeMrEquality.insertItemAt("none", 0);
+		_cmbAttributeMrOrdering.insertItemAt("none", 0);
+		_cmbAttributeMrSubstring.insertItemAt("none", 0);
+		Vector vMatchingRules = new Vector (_htMatchingRuleStrings.keySet());
+		Collections.sort(vMatchingRules);
+		Enumeration matchingrules = vMatchingRules.elements();
+		while (matchingrules.hasMoreElements()) {
+			String item = (String)matchingrules.nextElement();
+			// Don't add the matching rule if it's syntax isn't in the hashtable of
+			// syntax strings.  This is to avoid including matching rules that use the
+			// substring assertion syntax, which we don't support.
+			if ((item != null) && (_htSyntaxStrings.get(_htMatchingRuleStrings.get(item)) != null)) {
+				_cmbAttributeMrEquality.addItem(item);
+				_cmbAttributeMrOrdering.addItem(item);
+				_cmbAttributeMrSubstring.addItem(item);
+			}
+		}
+
+		// layout the widgets
+		// create a panel to hold things
+		JPanel panel = new JPanel(new GridBagLayout());
 		panel.setBorder( new EmptyBorder( 0, 0, 0, 0 ) );
 		GridBagConstraints gbc = new GridBagConstraints();	
 		int different = UIFactory.getDifferentSpace();
@@ -680,6 +869,45 @@ class AttributePanel extends BlankPanel {
 		gbc.insets = right;
 		panel.add(_cmbAttributeSyntax, gbc);
 
+		gbc.fill = gbc.NONE;
+		gbc.anchor = gbc.NORTHEAST;
+		gbc.gridwidth = gbc.RELATIVE;
+		gbc.weightx = 0;
+		gbc.insets = left;
+		panel.add(_lAttributeMrEquality, gbc);
+		gbc.fill = gbc.HORIZONTAL;
+		gbc.anchor = gbc.WEST;
+		gbc.weightx = 1;
+		gbc.gridwidth = gbc.REMAINDER;
+		gbc.insets = right;
+		panel.add(_cmbAttributeMrEquality, gbc);
+
+		gbc.fill = gbc.NONE;
+		gbc.anchor = gbc.NORTHEAST;
+		gbc.gridwidth = gbc.RELATIVE;
+		gbc.weightx = 0;
+		gbc.insets = left;
+		panel.add(_lAttributeMrOrdering, gbc);
+		gbc.fill = gbc.HORIZONTAL;
+		gbc.anchor = gbc.WEST;
+		gbc.weightx = 1;
+		gbc.gridwidth = gbc.REMAINDER;
+		gbc.insets = right;
+		panel.add(_cmbAttributeMrOrdering, gbc);
+
+		gbc.fill = gbc.NONE;
+		gbc.anchor = gbc.NORTHEAST;
+		gbc.gridwidth = gbc.RELATIVE;
+		gbc.weightx = 0;
+		gbc.insets = left;
+		panel.add(_lAttributeMrSubstring, gbc);
+		gbc.fill = gbc.HORIZONTAL;
+		gbc.anchor = gbc.WEST;
+		gbc.weightx = 1;
+		gbc.gridwidth = gbc.REMAINDER;
+		gbc.insets = right;
+		panel.add(_cmbAttributeMrSubstring, gbc);
+
 		gbc.fill = gbc.NONE;
 		gbc.weightx = 0.0;
 		gbc.anchor = gbc.NORTHEAST;
@@ -704,12 +932,52 @@ class AttributePanel extends BlankPanel {
 			if (syntax != null) {
 				_cmbAttributeSyntax.setSelectedItem( syntax );
 			}
+
+			String [] mr_eq_vals = _las.getQualifier("EQUALITY");
+			if ((mr_eq_vals != null) && (mr_eq_vals.length > 0)) {
+				String mr_eq = mr_eq_vals[0];
+				if (mr_eq != null) {
+					_cmbAttributeMrEquality.setSelectedItem( mr_eq );
+				} else {
+					_cmbAttributeMrEquality.setSelectedIndex(0);
+				}
+			} else {
+				_cmbAttributeMrEquality.setSelectedIndex(0);
+			}
+
+			String [] mr_ord_vals = _las.getQualifier("ORDERING");
+			if ((mr_ord_vals != null) && (mr_ord_vals.length > 0)) {
+				String mr_ord = mr_ord_vals[0];
+				if (mr_ord != null) {
+					_cmbAttributeMrOrdering.setSelectedItem( mr_ord );
+				} else {
+					_cmbAttributeMrOrdering.setSelectedIndex(0);
+				}
+			} else {
+				_cmbAttributeMrOrdering.setSelectedIndex(0);
+			}
+
+			String [] mr_sub_vals = _las.getQualifier("SUBSTR");
+			if ((mr_sub_vals != null) && (mr_sub_vals.length > 0)) {
+				String mr_sub = mr_sub_vals[0];
+				if (mr_sub != null) {
+					_cmbAttributeMrSubstring.setSelectedItem( mr_sub );
+				} else {
+					_cmbAttributeMrSubstring.setSelectedIndex(0);
+				}
+			} else {
+				_cmbAttributeMrSubstring.setSelectedIndex(0);
+			}
+
 			_ckbAttributeIsMulti.setSelected( !_las.isSingleValued() );
 		} else {
 			/* Give a default value */
-			_tfAttributeName.setText(DSUtil._resource.getString(
-														 PANEL_NAME,
-														 "newname-default"));
+			_tfAttributeName.setText(DSUtil._resource.getString(PANEL_NAME, "newname-default"));
+
+			/* Select none for all matching rules */
+			_cmbAttributeMrEquality.setSelectedIndex(0);
+			_cmbAttributeMrOrdering.setSelectedIndex(0);
+			_cmbAttributeMrSubstring.setSelectedIndex(0);
 		}
 		return panel;
 	}
@@ -767,11 +1035,14 @@ class AttributePanel extends BlankPanel {
 	 *
 	 * @param e Event indicating what changed
 	 */
-    public void itemStateChanged(ItemEvent e) {
-		if (e.getSource().equals(_cmbAttributeSyntax)) {
+	public void itemStateChanged(ItemEvent e) {
+		if (e.getSource().equals(_cmbAttributeSyntax) ||
+		    e.getSource().equals(_cmbAttributeMrEquality) ||
+		    e.getSource().equals(_cmbAttributeMrOrdering) ||
+		    e.getSource().equals(_cmbAttributeMrSubstring)) {
 			checkOkay();
 		}
-    }
+	}
 
 
 	private JLabel _lAttributeAliases;
@@ -779,16 +1050,23 @@ class AttributePanel extends BlankPanel {
 	private JLabel _lAttributeName;
 	private JLabel _lAttributeDesc;
 	private JLabel _lAttributeSyntax;
+	private JLabel _lAttributeMrEquality;
+	private JLabel _lAttributeMrOrdering;
+	private JLabel _lAttributeMrSubstring;
 	private JTextField _tfAttributeName; // new attribute name
 	private JTextField _tfAttributeAliases; // aliases
 	private JTextField _tfAttributeOID; // oid for new attribute (optional)
 	private JTextField _tfAttributeDesc; // attribute description (optional)
 	private JCheckBox _ckbAttributeIsMulti; // true if attr is multivalued
 	private JComboBox _cmbAttributeSyntax; // syntax for new attribute
+	private JComboBox _cmbAttributeMrEquality; //equality matching rule
+	private JComboBox _cmbAttributeMrOrdering; //ordering matching rule
+	private JComboBox _cmbAttributeMrSubstring; //substring matching rule
 	private LDAPAttributeSchema _las = null;
 	private boolean _create = false;
 	private SimpleDialog _dlg;
 	private Hashtable _htSyntaxStrings = null;
+	private Hashtable _htMatchingRuleStrings = null;
 
 	static final public String PANEL_NAME = "schemaattributes"; // name of panel in resource file
 }
