@@ -382,6 +382,10 @@ public class BlankPanel extends JPanel
         while (components.hasMoreElements()) {
 			int thisResult = DSEntry.DSE_VALID_NOMOD;
             JComponent comp = (JComponent)components.nextElement();
+            if (comp.isEnabled() == false){
+                // No need to validate disabled components
+                continue;
+            }
 			Vector v = (Vector)_componentMapDSEntryTable.get( comp );
 			Enumeration entries = v.elements();
 			if (_verbose) {
