@@ -185,7 +185,12 @@ public class DSEntrySet {
                 if (lda == null && entry != null) {
                     Debug.println( "DSEntrySet.getAttributes(): failed to get " +
                                    "attribute " + attrName + " in " + entry.getDN());
-                    haveAllAttrs = false; // missing at least one attr value
+                    // missing at least one attr value
+                    // haveAllAttrs = false;
+                    // Instead of returning an auth error, create an empty attr
+                    Debug.println( "DSEntrySet.getAttributes(): created " +
+                                   "attribute " + attrName + " in " + entry.getDN());
+                    lda = new LDAPAttribute(attrName, ""); 
                 }
 
                 // loop through all of the DSEntrys which
