@@ -751,9 +751,9 @@ class EncryptionConfigData {
 									   "+rsa_fips_des_sha," +
 	                                   "+rsa_3des_sha," +
 									   "+rsa_fips_3des_sha," +
-									   "+fortezza," +
-									   "+fortezza_rc4_128_sha," +
-									   "+fortezza_null," +
+									   "-fortezza," +
+									   "-fortezza_rc4_128_sha," +
+									   "-fortezza_null," +
 									   "+tls_rsa_export1024_with_rc4_56_sha," +
 	                                   "+tls_rsa_export1024_with_des_cbc_sha," +
 	                                   "+tls_rsa_aes_128_sha," +
