@@ -596,7 +596,9 @@ abstract public class LogPanel extends BlankPanel {
 				try {
 					int logSizeValue = Integer.parseInt(logSize);
 					int maxDiskSpaceValue = Integer.parseInt(maxDiskSpace);
-					if (logSizeValue > maxDiskSpaceValue) {
+					// If max disk space is unlimited (-1), there's no need to compare
+					// it with the individual log size.
+					if ((maxDiskSpaceValue >= 0) && (logSizeValue > maxDiskSpaceValue)) {
 						setChangeState(_lLogSize, CHANGE_STATE_ERROR );
 						setChangeState(_lMaxDiskSpace, CHANGE_STATE_ERROR );	
 						clearValidFlag();
