@@ -93,7 +93,8 @@ public class MappingNodeSettingPanel extends BlankPanel
         _myPanel.add( _NodeLabel, gbc );				
 
 	_NodeText = new JLabel();
-	_NodeText.setText( LDAPDN.explodeDN(_entry.getDN(),true)[0]);
+	String suffixval = MappingUtils.getMappingNodeName(_entry);
+	_NodeText.setText(suffixval);
 	gbc.gridx      = 1;
 	gbc.anchor = gbc.WEST;
         _myPanel.add( _NodeText, gbc );
