@@ -918,11 +918,6 @@ public class NewChainingInstancePanel extends BlankPanel
 		}				
 	    } else if ( _rbExistingNode.isSelected() ) {
 		// Add backend instance in selected Mapping Node				   
-		String dn_instMapping = "cn=" + 
-		    MappingUtils.Quote( (String) _comboMapping.getSelectedItem() ) + 
-		    "," + 
-		    CONFIG_MAPPING;
-		Debug.println("okCallback updating :" + dn_instMapping);
 		LDAPModificationSet mods = new LDAPModificationSet();
 			
 		LDAPAttribute backend_instMapping = new LDAPAttribute( "nsslapd-backend",
@@ -930,6 +925,9 @@ public class NewChainingInstancePanel extends BlankPanel
 		mods.add( LDAPModification.ADD, backend_instMapping );
 		_model.setWaitCursor( true );
 		LDAPConnection ldc = _model.getServerInfo().getLDAPConnection();
+		String dn_instMapping = MappingUtils.getMappingNodeForSuffix(ldc,
+			(String) _comboMapping.getSelectedItem());
+		Debug.println("okCallback updating :" + dn_instMapping);
 		try {
 		    ldc.modify(dn_instMapping,  mods );					
 		} catch (LDAPException e) {
