@@ -249,6 +249,9 @@ public class PasswordPolicyPanel extends BlankPanel {
         rememberPanel.add(_tfRememberValue);
         rememberPanel.add(Box.createHorizontalStrut(space));
         rememberPanel.add(_rememberLabel2);
+
+        enableChange();
+        enableHistory();
     }
 
     protected void createSyntaxArea( Container myContainer ) {
@@ -475,6 +478,7 @@ public class PasswordPolicyPanel extends BlankPanel {
                               1, 1, 1.0, 0.0,
                               GridBagConstraints.WEST, GridBagConstraints.NONE,
                               0, 0, SuiConstants.COMPONENT_SPACE, 0);
+        enableSyntax();
     }
 
 
@@ -512,7 +516,7 @@ public class PasswordPolicyPanel extends BlankPanel {
                 
         DSEntrySet entries = getDSEntrySet();
 
-        DSEntryExpire expiresInDSEntry = new DSEntryExpire("0", _rbExpiresIn);
+        DSEntryExpire expiresInDSEntry = new DSEntryExpire(null, _rbExpiresIn);
         entries.add(_policyspecdn, EXPIRES_ATTR_NAME,
                     expiresInDSEntry);
 		setComponentTable(_rbExpiresIn, expiresInDSEntry);        
@@ -582,7 +586,8 @@ public class PasswordPolicyPanel extends BlankPanel {
         _graceLoginLabel2.add(Box.createHorizontalStrut(space));
         _graceLoginLabel2.setHorizontalAlignment(SwingConstants.LEFT);
         graceLoginPanel.add(_graceLoginLabel2);
-        
+
+        enableExpire();
     }
 
     class DSEntryExpire extends DSEntryBoolean{
@@ -888,47 +893,46 @@ public class PasswordPolicyPanel extends BlankPanel {
 	    } else {
 			enable = _cbCheckSyntax.isSelected();
 		}
-
-		_minLengthLabel.setEnabled( enable );
-		_minLengthLabel.repaint();
-		_tfMinLengthValue.setEnabled( enable );
-		_tfMinLengthValue.repaint();
-                _minDigitsLabel.setEnabled( enable );
-                _minDigitsLabel.repaint();
-                _tfMinDigitsValue.setEnabled( enable );
-                _tfMinDigitsValue.repaint();
-                _minAlphasLabel.setEnabled( enable );
-                _minAlphasLabel.repaint();
-                _tfMinAlphasValue.setEnabled( enable );
-                _tfMinAlphasValue.repaint();
-                _minUppersLabel.setEnabled( enable );
-                _minUppersLabel.repaint();
-                _tfMinUppersValue.setEnabled( enable );
-                _tfMinUppersValue.repaint();
-                _minLowersLabel.setEnabled( enable );
-                _minLowersLabel.repaint();
-                _tfMinLowersValue.setEnabled( enable );
-                _tfMinLowersValue.repaint();
-                _minSpecialsLabel.setEnabled( enable );
-                _minSpecialsLabel.repaint();
-                _tfMinSpecialsValue.setEnabled( enable );
-                _tfMinSpecialsValue.repaint();
-                _min8bitLabel.setEnabled( enable );
-                _min8bitLabel.repaint();
-                _tfMin8bitValue.setEnabled( enable );
-                _tfMin8bitValue.repaint();
-                _maxRepeatsLabel.setEnabled( enable );
-                _maxRepeatsLabel.repaint();
-                _tfMaxRepeatsValue.setEnabled( enable );
-                _tfMaxRepeatsValue.repaint();
-                _minCategoriesLabel.setEnabled( enable );
-                _minCategoriesLabel.repaint();
-                _tfMinCategoriesValue.setEnabled( enable );
-                _tfMinCategoriesValue.repaint();
-                _minTokenLengthLabel.setEnabled( enable );
-                _minTokenLengthLabel.repaint();
-                _tfMinTokenLengthValue.setEnabled( enable );
-                _tfMinTokenLengthValue.repaint();
+			_minLengthLabel.setEnabled( enable );
+			_minLengthLabel.repaint();
+			_tfMinLengthValue.setEnabled( enable );
+			_tfMinLengthValue.repaint();
+			_minDigitsLabel.setEnabled( enable );
+			_minDigitsLabel.repaint();
+			_tfMinDigitsValue.setEnabled( enable );
+			_tfMinDigitsValue.repaint();
+			_minAlphasLabel.setEnabled( enable );
+			_minAlphasLabel.repaint();
+			_tfMinAlphasValue.setEnabled( enable );
+			_tfMinAlphasValue.repaint();
+			_minUppersLabel.setEnabled( enable );
+			_minUppersLabel.repaint();
+			_tfMinUppersValue.setEnabled( enable );
+			_tfMinUppersValue.repaint();
+			_minLowersLabel.setEnabled( enable );
+			_minLowersLabel.repaint();
+			_tfMinLowersValue.setEnabled( enable );
+			_tfMinLowersValue.repaint();
+			_minSpecialsLabel.setEnabled( enable );
+			_minSpecialsLabel.repaint();
+			_tfMinSpecialsValue.setEnabled( enable );
+			_tfMinSpecialsValue.repaint();
+			_min8bitLabel.setEnabled( enable );
+			_min8bitLabel.repaint();
+			_tfMin8bitValue.setEnabled( enable );
+			_tfMin8bitValue.repaint();
+			_maxRepeatsLabel.setEnabled( enable );
+			_maxRepeatsLabel.repaint();
+			_tfMaxRepeatsValue.setEnabled( enable );
+			_tfMaxRepeatsValue.repaint();
+			_minCategoriesLabel.setEnabled( enable );
+			_minCategoriesLabel.repaint();
+			_tfMinCategoriesValue.setEnabled( enable );
+			_tfMinCategoriesValue.repaint();
+			_minTokenLengthLabel.setEnabled( enable );
+			_minTokenLengthLabel.repaint();
+			_tfMinTokenLengthValue.setEnabled( enable );
+			_tfMinTokenLengthValue.repaint();
     }
 
 	private void enableChange (){
@@ -1322,7 +1326,7 @@ public class PasswordPolicyPanel extends BlankPanel {
     private static final String HISTORY_NUM_DN = "cn=config";
     private static final String HISTORY_NUM_ATTR_NAME =
         "passwordInHistory";
-    private static final int HISTORY_NUM_MIN_VAL = 2;
+    private static final int HISTORY_NUM_MIN_VAL = 1;
     private static final int HISTORY_NUM_MAX_VAL = 24;
 
     private static final int DAY_TO_SEC_FACTOR = 86400;
