@@ -19,16 +19,29 @@
 
 package com.netscape.admin.dirserv.panel.replication;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
 import java.util.Vector;
-import java.awt.event.*;
-import javax.swing.*;
-import javax.swing.event.*;
+
+import javax.swing.Box;
+import javax.swing.ButtonGroup;
+import javax.swing.JButton;
+import javax.swing.JCheckBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JRadioButton;
+import javax.swing.JTextField;
+import javax.swing.event.DocumentEvent;
+import javax.swing.event.DocumentListener;
+
 import com.netscape.admin.dirserv.panel.UIFactory;
-import com.netscape.admin.dirserv.wizard.*;
-import com.netscape.management.client.util.ResourceSet;
+import com.netscape.admin.dirserv.wizard.IWizardPanel;
+import com.netscape.admin.dirserv.wizard.WizardInfo;
 import com.netscape.management.client.util.Debug;
-import netscape.ldap.*;
 
 /**
  * Schedule Panel for Replication Agreement
@@ -177,7 +190,7 @@ public class WAgreementSchedulePanel extends WAgreementPanel
         _activeColor = _startHr.getBackground();
         ReplicationTool.resetGBC(gbc);
         gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.weightx= 1.0;
         timePanel.add(_startHr, gbc);
 
         _startMin = UIFactory.makeJTextField(null,"00",3);
@@ -185,7 +198,7 @@ public class WAgreementSchedulePanel extends WAgreementPanel
 		_startMin.getDocument().addDocumentListener(this);
         ReplicationTool.resetGBC(gbc);
         gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.weightx= 1.0;
         timePanel.add(_startMin, gbc);
 
         JLabel and = UIFactory.makeJLabel(_section, "and", _resource);		
@@ -199,7 +212,7 @@ public class WAgreementSchedulePanel extends WAgreementPanel
 		_endHr.getDocument().addDocumentListener(this);
         ReplicationTool.resetGBC(gbc);
         gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.weightx= 1.0;
         timePanel.add(_endHr, gbc);
 
         _endMin = UIFactory.makeJTextField(null,"00",3);
@@ -207,7 +220,7 @@ public class WAgreementSchedulePanel extends WAgreementPanel
 		_endMin.getDocument().addDocumentListener(this);
         ReplicationTool.resetGBC(gbc);
         gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.weightx= 1.0;
         timePanel.add(_endMin, gbc);
 
 		gbc.fill = gbc.HORIZONTAL;
@@ -386,8 +399,8 @@ public class WAgreementSchedulePanel extends WAgreementPanel
 	private void populateData() {
 	    String time = "";
 	    if ((_wizardInfo.getDate() != null) &&
-			(( (Vector)_wizardInfo.getDate()).size() >0)) {
-	        time = (String)((Vector)_wizardInfo.getDate()).firstElement();
+			(_wizardInfo.getDate().size() >0)) {
+	        time = (String)_wizardInfo.getDate().firstElement();
 	    }
 	    setSchedule(time);
 	}
